==> estateplat-common-1.2.4-20210429.092621-739-sources.jar: cn/gtmap/estateplat/model/exchange/national/ZhK.java <==
package cn.gtmap.estateplat.model.exchange.national;

import cn.gtmap.estateplat.utils.JaxbBigdecimalAdapter;
import cn.gtmap.estateplat.utils.JaxbDoubleEightAdapter;
import cn.gtmap.estateplat.utils.JaxbIntegerAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 宗海空间属性
 * Created by xhc on 2015/11/20.
 */
@XmlRootElement(name = "ZH_K_105")
public class ZhK implements Serializable, AccessData {
    private String bdcdyh;//不动产单元号
    private Integer zdx;//子对象
    private Integer xh;//序号
    private Double xzb;//X坐标
    private Double yzb;//Y坐标
    private Date updatetime;//更新时间
    private Date createtime;//创建时间

    @XmlAttribute(name = "BDCDYH")
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    @XmlAttribute(name = "ZDX")
    public Integer getZdx() {
        return zdx;
    }

    public void setZdx(Integer zdx) {
        this.zdx = zdx;
    }

    @XmlAttribute(name = "XH")
    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    @XmlAttribute(name = "XZB")
    @XmlJavaTypeAdapter(JaxbDoubleEightAdapter.class)
    public Double getXzb() {
        return xzb;
    }

    public void setXzb(Double xzb) {
        this.xzb = xzb;
    }

    @XmlAttribute(name = "YZB")
    @XmlJavaTypeAdapter(JaxbDoubleEightAdapter.class)
    public Double getYzb() {
        return yzb;
    }

    public void setYzb(Double yzb) {
        this.yzb = yzb;
    }

    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
}

==> estateplat-common-1.2.4-20210914.120836-872-sources.jar: cn/gtmap/estateplat/model/exchange/national/ZhK.java <==
package cn.gtmap.estateplat.model.exchange.national;

import cn.gtmap.estateplat.utils.JaxbBigdecimalAdapter;
import cn.gtmap.estateplat.utils.JaxbDoubleEightAdapter;
import cn.gtmap.estateplat.utils.JaxbIntegerAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

/**
 * 宗海空间属性
 * Created by xhc on 2015/11/20.
 */
@XmlRootElement(name = "ZH_K_105")
public class ZhK implements Serializable, AccessData {
    private String bdcdyh;//不动产单元号
    private Integer zdx;//子对象
    private Integer xh;//序号
    private Double xzb;//X坐标
    private Double yzb;//Y坐标
    private Date updatetime;//更新时间
    private Date createtime;//创建时间
    private Double zzb;
    @XmlAttribute(name = "ZZB")
    public Double getZzb() {
        return zzb;
    }

    public void setZzb(Double zzb) {
        this.zzb = zzb;
    }

    @XmlAttribute(name = "BDCDYH")
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    @XmlAttribute(name = "ZDX")
    public Integer getZdx() {
        return zdx;
    }

    public void setZdx(Integer zdx) {
        this.zdx = zdx;
    }

    @XmlAttribute(name = "XH")
    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    @XmlAttribute(name = "XZB")
    @XmlJavaTypeAdapter(JaxbDoubleEightAdapter.class)
    public Double getXzb() {
        return xzb;
    }

    public void setXzb(Double xzb) {
        this.xzb = xzb;
    }

    @XmlAttribute(name = "YZB")
    @XmlJavaTypeAdapter(JaxbDoubleEightAdapter.class)
    public Double getYzb() {
        return yzb;
    }

    public void setYzb(Double yzb) {
        this.yzb = yzb;
    }

    @XmlTransient
    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    @XmlTransient
    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }
}
